# gefslim

[![Tests][badge-tests]][link-tests]
[![Documentation][badge-docs]][link-docs]

[badge-tests]: https://img.shields.io/github/actions/workflow/status/timtreis/gefslim/test.yaml?branch=main
[link-tests]: https://github.com/timtreis/gefslim/actions/workflows/test.yml
[badge-docs]: https://img.shields.io/readthedocs/gefslim

A minimal reader for .gef files

## Getting started

Please refer to the [documentation][link-docs]. In particular, the

-   [API documentation][link-api].

## Installation

You need to have Python 3.9 or newer installed on your system. If you don't have
Python installed, we recommend installing [Mambaforge](https://github.com/conda-forge/miniforge#mambaforge).

There are several alternative options to install gefslim:

<!--
1) Install the latest release of `gefslim` from `PyPI <https://pypi.org/project/gefslim/>`_:

```bash
pip install gefslim
```
-->

1. Install the latest development version:

```bash
pip install git+https://github.com/timtreis/gefslim.git@main
```

[scverse-discourse]: https://discourse.scverse.org/
[issue-tracker]: https://github.com/timtreis/gefslim/issues
[changelog]: https://gefslim.readthedocs.io/latest/changelog.html
[link-docs]: https://gefslim.readthedocs.io
[link-api]: https://gefslim.readthedocs.io/latest/api.html
